@@ -1,47 +1,50 @@
-#include <tree_sitter/parser.h>
+#include "tree_sitter/parser.h"
 
 #if defined(__GNUC__) || defined(__clang__)
-#pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wmissing-field-initializers"
 #endif
 
 #define LANGUAGE_VERSION 14
 #define STATE_COUNT 29
 #define LARGE_STATE_COUNT 4
-#define SYMBOL_COUNT 25
+#define SYMBOL_COUNT 29
 #define ALIAS_COUNT 1
-#define TOKEN_COUNT 15
+#define TOKEN_COUNT 19
 #define EXTERNAL_TOKEN_COUNT 0
 #define FIELD_COUNT 0
 #define MAX_ALIAS_SEQUENCE_LENGTH 3
 #define PRODUCTION_ID_COUNT 2
 
-enum {
+enum ts_symbol_identifiers {
   aux_sym_code_token1 = 1,
   anon_sym_PERCENT_PERCENT_GT = 2,
   aux_sym_content_token1 = 3,
   anon_sym_LT_PERCENT_PERCENT = 4,
   anon_sym_LT_PERCENT = 5,
   anon_sym_LT_PERCENT_ = 6,
-  anon_sym_PERCENT_GT = 7,
-  anon_sym_DASH_PERCENT_GT = 8,
-  anon_sym__PERCENT_GT = 9,
-  anon_sym_LT_PERCENT_EQ = 10,
-  anon_sym_LT_PERCENT_DASH = 11,
-  anon_sym_EQ_PERCENT_GT = 12,
-  anon_sym_LT_PERCENT_POUND = 13,
-  anon_sym_LT_PERCENTgraphql = 14,
-  sym_template = 15,
-  sym_code = 16,
-  sym_content = 17,
-  sym_directive = 18,
-  sym_output_directive = 19,
-  sym_comment_directive = 20,
-  sym_graphql_directive = 21,
-  aux_sym_template_repeat1 = 22,
-  aux_sym_code_repeat1 = 23,
-  aux_sym_content_repeat1 = 24,
-  alias_sym_comment = 25,
+  anon_sym_LT_PERCENT_PIPE = 7,
+  anon_sym_PERCENT_GT = 8,
+  anon_sym_DASH_PERCENT_GT = 9,
+  anon_sym__PERCENT_GT = 10,
+  anon_sym_LT_PERCENT_EQ = 11,
+  anon_sym_LT_PERCENT_EQ_EQ = 12,
+  anon_sym_LT_PERCENT_PIPE_EQ = 13,
+  anon_sym_LT_PERCENT_PIPE_EQ_EQ = 14,
+  anon_sym_LT_PERCENT_DASH = 15,
+  anon_sym_EQ_PERCENT_GT = 16,
+  anon_sym_LT_PERCENT_POUND = 17,
+  anon_sym_LT_PERCENTgraphql = 18,
+  sym_template = 19,
+  sym_code = 20,
+  sym_content = 21,
+  sym_directive = 22,
+  sym_output_directive = 23,
+  sym_comment_directive = 24,
+  sym_graphql_directive = 25,
+  aux_sym_template_repeat1 = 26,
+  aux_sym_code_repeat1 = 27,
+  aux_sym_content_repeat1 = 28,
+  alias_sym_comment = 29,
 };
 
 static const char * const ts_symbol_names[] = {
@@ -52,10 +55,14 @@ static const char * const ts_symbol_names[] = {
   [anon_sym_LT_PERCENT_PERCENT] = "<%%",
   [anon_sym_LT_PERCENT] = "<%",
   [anon_sym_LT_PERCENT_] = "<%_",
+  [anon_sym_LT_PERCENT_PIPE] = "<%|",
   [anon_sym_PERCENT_GT] = "%>",
   [anon_sym_DASH_PERCENT_GT] = "-%>",
   [anon_sym__PERCENT_GT] = "_%>",
   [anon_sym_LT_PERCENT_EQ] = "<%=",
+  [anon_sym_LT_PERCENT_EQ_EQ] = "<%==",
+  [anon_sym_LT_PERCENT_PIPE_EQ] = "<%|=",
+  [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = "<%|==",
   [anon_sym_LT_PERCENT_DASH] = "<%-",
   [anon_sym_EQ_PERCENT_GT] = "=%>",
   [anon_sym_LT_PERCENT_POUND] = "<%#",
@@ -81,10 +88,14 @@ static const TSSymbol ts_symbol_map[] = {
   [anon_sym_LT_PERCENT_PERCENT] = anon_sym_LT_PERCENT_PERCENT,
   [anon_sym_LT_PERCENT] = anon_sym_LT_PERCENT,
   [anon_sym_LT_PERCENT_] = anon_sym_LT_PERCENT_,
+  [anon_sym_LT_PERCENT_PIPE] = anon_sym_LT_PERCENT_PIPE,
   [anon_sym_PERCENT_GT] = anon_sym_PERCENT_GT,
   [anon_sym_DASH_PERCENT_GT] = anon_sym_DASH_PERCENT_GT,
   [anon_sym__PERCENT_GT] = anon_sym__PERCENT_GT,
   [anon_sym_LT_PERCENT_EQ] = anon_sym_LT_PERCENT_EQ,
+  [anon_sym_LT_PERCENT_EQ_EQ] = anon_sym_LT_PERCENT_EQ_EQ,
+  [anon_sym_LT_PERCENT_PIPE_EQ] = anon_sym_LT_PERCENT_PIPE_EQ,
+  [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = anon_sym_LT_PERCENT_PIPE_EQ_EQ,
   [anon_sym_LT_PERCENT_DASH] = anon_sym_LT_PERCENT_DASH,
   [anon_sym_EQ_PERCENT_GT] = anon_sym_EQ_PERCENT_GT,
   [anon_sym_LT_PERCENT_POUND] = anon_sym_LT_PERCENT_POUND,
@@ -131,6 +142,10 @@ static const TSSymbolMetadata ts_symbol_metadata[] = {
     .visible = true,
     .named = false,
   },
+  [anon_sym_LT_PERCENT_PIPE] = {
+    .visible = true,
+    .named = false,
+  },
   [anon_sym_PERCENT_GT] = {
     .visible = true,
     .named = false,
@@ -147,6 +162,18 @@ static const TSSymbolMetadata ts_symbol_metadata[] = {
     .visible = true,
     .named = false,
   },
+  [anon_sym_LT_PERCENT_EQ_EQ] = {
+    .visible = true,
+    .named = false,
+  },
+  [anon_sym_LT_PERCENT_PIPE_EQ] = {
+    .visible = true,
+    .named = false,
+  },
+  [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = {
+    .visible = true,
+    .named = false,
+  },
   [anon_sym_LT_PERCENT_DASH] = {
     .visible = true,
     .named = false,
@@ -242,8 +269,8 @@ static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
   [15] = 15,
   [16] = 16,
   [17] = 17,
-  [18] = 16,
-  [19] = 17,
+  [18] = 17,
+  [19] = 16,
   [20] = 20,
   [21] = 21,
   [22] = 16,
@@ -292,13 +319,13 @@ static bool ts_lex(TSLexer *lexer, TSStateId state) {
       if (lookahead == '>') ADVANCE(22);
       END_STATE();
     case 5:
-      if (lookahead == '>') ADVANCE(29);
+      if (lookahead == '>') ADVANCE(30);
       END_STATE();
     case 6:
-      if (lookahead == '>') ADVANCE(33);
+      if (lookahead == '>') ADVANCE(37);
       END_STATE();
     case 7:
-      if (lookahead == '>') ADVANCE(30);
+      if (lookahead == '>') ADVANCE(31);
       END_STATE();
     case 8:
       if (lookahead == 'a') ADVANCE(11);
@@ -307,7 +334,7 @@ static bool ts_lex(TSLexer *lexer, TSStateId state) {
       if (lookahead == 'h') ADVANCE(12);
       END_STATE();
     case 10:
-      if (lookahead == 'l') ADVANCE(35);
+      if (lookahead == 'l') ADVANCE(39);
       END_STATE();
     case 11:
       if (lookahead == 'p') ADVANCE(9);
@@ -332,7 +359,7 @@ static bool ts_lex(TSLexer *lexer, TSStateId state) {
     case 17:
       ACCEPT_TOKEN(aux_sym_code_token1);
       if (lookahead == '%') ADVANCE(4);
-      if (lookahead == '>') ADVANCE(28);
+      if (lookahead == '>') ADVANCE(29);
       END_STATE();
     case 18:
       ACCEPT_TOKEN(aux_sym_code_token1);
@@ -371,38 +398,54 @@ static bool ts_lex(TSLexer *lexer, TSStateId state) {
       END_STATE();
     case 26:
       ACCEPT_TOKEN(anon_sym_LT_PERCENT);
-      if (lookahead == '#') ADVANCE(34);
+      if (lookahead == '#') ADVANCE(38);
       if (lookahead == '%') ADVANCE(25);
-      if (lookahead == '-') ADVANCE(32);
-      if (lookahead == '=') ADVANCE(31);
+      if (lookahead == '-') ADVANCE(36);
+      if (lookahead == '=') ADVANCE(32);
       if (lookahead == '_') ADVANCE(27);
       if (lookahead == 'g') ADVANCE(13);
+      if (lookahead == '|') ADVANCE(28);
       END_STATE();
     case 27:
       ACCEPT_TOKEN(anon_sym_LT_PERCENT_);
       END_STATE();
     case 28:
-      ACCEPT_TOKEN(anon_sym_PERCENT_GT);
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_PIPE);
+      if (lookahead == '=') ADVANCE(34);
       END_STATE();
     case 29:
-      ACCEPT_TOKEN(anon_sym_DASH_PERCENT_GT);
+      ACCEPT_TOKEN(anon_sym_PERCENT_GT);
       END_STATE();
     case 30:
-      ACCEPT_TOKEN(anon_sym__PERCENT_GT);
+      ACCEPT_TOKEN(anon_sym_DASH_PERCENT_GT);
       END_STATE();
     case 31:
-      ACCEPT_TOKEN(anon_sym_LT_PERCENT_EQ);
+      ACCEPT_TOKEN(anon_sym__PERCENT_GT);
       END_STATE();
     case 32:
-      ACCEPT_TOKEN(anon_sym_LT_PERCENT_DASH);
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_EQ);
+      if (lookahead == '=') ADVANCE(33);
       END_STATE();
     case 33:
-      ACCEPT_TOKEN(anon_sym_EQ_PERCENT_GT);
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_EQ_EQ);
       END_STATE();
     case 34:
-      ACCEPT_TOKEN(anon_sym_LT_PERCENT_POUND);
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_PIPE_EQ);
+      if (lookahead == '=') ADVANCE(35);
       END_STATE();
     case 35:
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_PIPE_EQ_EQ);
+      END_STATE();
+    case 36:
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_DASH);
+      END_STATE();
+    case 37:
+      ACCEPT_TOKEN(anon_sym_EQ_PERCENT_GT);
+      END_STATE();
+    case 38:
+      ACCEPT_TOKEN(anon_sym_LT_PERCENT_POUND);
+      END_STATE();
+    case 39:
       ACCEPT_TOKEN(anon_sym_LT_PERCENTgraphql);
       END_STATE();
     default:
@@ -425,8 +468,8 @@ static const TSLexMode ts_lex_modes[STATE_COUNT] = {
   [11] = {.lex_state = 14},
   [12] = {.lex_state = 14},
   [13] = {.lex_state = 14},
-  [14] = {.lex_state = 1},
-  [15] = {.lex_state = 2},
+  [14] = {.lex_state = 2},
+  [15] = {.lex_state = 1},
   [16] = {.lex_state = 1},
   [17] = {.lex_state = 1},
   [18] = {.lex_state = 2},
@@ -453,7 +496,29 @@ static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
     [anon_sym_EQ_PERCENT_GT] = ACTIONS(1),
   },
   [1] = {
-    [sym_template] = STATE(28),
+    [sym_template] = STATE(26),
+    [sym_content] = STATE(2),
+    [sym_directive] = STATE(2),
+    [sym_output_directive] = STATE(2),
+    [sym_comment_directive] = STATE(2),
+    [sym_graphql_directive] = STATE(2),
+    [aux_sym_template_repeat1] = STATE(2),
+    [aux_sym_content_repeat1] = STATE(4),
+    [ts_builtin_sym_end] = ACTIONS(3),
+    [aux_sym_content_token1] = ACTIONS(5),
+    [anon_sym_LT_PERCENT_PERCENT] = ACTIONS(7),
+    [anon_sym_LT_PERCENT] = ACTIONS(9),
+    [anon_sym_LT_PERCENT_] = ACTIONS(11),
+    [anon_sym_LT_PERCENT_PIPE] = ACTIONS(9),
+    [anon_sym_LT_PERCENT_EQ] = ACTIONS(13),
+    [anon_sym_LT_PERCENT_EQ_EQ] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_PIPE_EQ] = ACTIONS(13),
+    [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_DASH] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_POUND] = ACTIONS(17),
+    [anon_sym_LT_PERCENTgraphql] = ACTIONS(19),
+  },
+  [2] = {
     [sym_content] = STATE(3),
     [sym_directive] = STATE(3),
     [sym_output_directive] = STATE(3),
@@ -461,425 +526,461 @@ static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
     [sym_graphql_directive] = STATE(3),
     [aux_sym_template_repeat1] = STATE(3),
     [aux_sym_content_repeat1] = STATE(4),
-    [ts_builtin_sym_end] = ACTIONS(3),
+    [ts_builtin_sym_end] = ACTIONS(21),
     [aux_sym_content_token1] = ACTIONS(5),
     [anon_sym_LT_PERCENT_PERCENT] = ACTIONS(7),
     [anon_sym_LT_PERCENT] = ACTIONS(9),
     [anon_sym_LT_PERCENT_] = ACTIONS(11),
+    [anon_sym_LT_PERCENT_PIPE] = ACTIONS(9),
     [anon_sym_LT_PERCENT_EQ] = ACTIONS(13),
-    [anon_sym_LT_PERCENT_DASH] = ACTIONS(13),
-    [anon_sym_LT_PERCENT_POUND] = ACTIONS(15),
-    [anon_sym_LT_PERCENTgraphql] = ACTIONS(17),
-  },
-  [2] = {
-    [sym_content] = STATE(2),
-    [sym_directive] = STATE(2),
-    [sym_output_directive] = STATE(2),
-    [sym_comment_directive] = STATE(2),
-    [sym_graphql_directive] = STATE(2),
-    [aux_sym_template_repeat1] = STATE(2),
-    [aux_sym_content_repeat1] = STATE(4),
-    [ts_builtin_sym_end] = ACTIONS(19),
-    [aux_sym_content_token1] = ACTIONS(21),
-    [anon_sym_LT_PERCENT_PERCENT] = ACTIONS(24),
-    [anon_sym_LT_PERCENT] = ACTIONS(27),
-    [anon_sym_LT_PERCENT_] = ACTIONS(30),
-    [anon_sym_LT_PERCENT_EQ] = ACTIONS(33),
-    [anon_sym_LT_PERCENT_DASH] = ACTIONS(33),
-    [anon_sym_LT_PERCENT_POUND] = ACTIONS(36),
-    [anon_sym_LT_PERCENTgraphql] = ACTIONS(39),
+    [anon_sym_LT_PERCENT_EQ_EQ] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_PIPE_EQ] = ACTIONS(13),
+    [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_DASH] = ACTIONS(15),
+    [anon_sym_LT_PERCENT_POUND] = ACTIONS(17),
+    [anon_sym_LT_PERCENTgraphql] = ACTIONS(19),
   },
   [3] = {
-    [sym_content] = STATE(2),
-    [sym_directive] = STATE(2),
-    [sym_output_directive] = STATE(2),
-    [sym_comment_directive] = STATE(2),
-    [sym_graphql_directive] = STATE(2),
-    [aux_sym_template_repeat1] = STATE(2),
+    [sym_content] = STATE(3),
+    [sym_directive] = STATE(3),
+    [sym_output_directive] = STATE(3),
+    [sym_comment_directive] = STATE(3),
+    [sym_graphql_directive] = STATE(3),
+    [aux_sym_template_repeat1] = STATE(3),
     [aux_sym_content_repeat1] = STATE(4),
-    [ts_builtin_sym_end] = ACTIONS(42),
-    [aux_sym_content_token1] = ACTIONS(5),
-    [anon_sym_LT_PERCENT_PERCENT] = ACTIONS(7),
-    [anon_sym_LT_PERCENT] = ACTIONS(9),
-    [anon_sym_LT_PERCENT_] = ACTIONS(11),
-    [anon_sym_LT_PERCENT_EQ] = ACTIONS(13),
-    [anon_sym_LT_PERCENT_DASH] = ACTIONS(13),
-    [anon_sym_LT_PERCENT_POUND] = ACTIONS(15),
-    [anon_sym_LT_PERCENTgraphql] = ACTIONS(17),
+    [ts_builtin_sym_end] = ACTIONS(23),
+    [aux_sym_content_token1] = ACTIONS(25),
+    [anon_sym_LT_PERCENT_PERCENT] = ACTIONS(28),
+    [anon_sym_LT_PERCENT] = ACTIONS(31),
+    [anon_sym_LT_PERCENT_] = ACTIONS(34),
+    [anon_sym_LT_PERCENT_PIPE] = ACTIONS(31),
+    [anon_sym_LT_PERCENT_EQ] = ACTIONS(37),
+    [anon_sym_LT_PERCENT_EQ_EQ] = ACTIONS(40),
+    [anon_sym_LT_PERCENT_PIPE_EQ] = ACTIONS(37),
+    [anon_sym_LT_PERCENT_PIPE_EQ_EQ] = ACTIONS(40),
+    [anon_sym_LT_PERCENT_DASH] = ACTIONS(40),
+    [anon_sym_LT_PERCENT_POUND] = ACTIONS(43),
+    [anon_sym_LT_PERCENTgraphql] = ACTIONS(46),
   },
 };
 
 static const uint16_t ts_small_parse_table[] = {
   [0] = 5,
-    ACTIONS(46), 1,
+    ACTIONS(51), 1,
       aux_sym_content_token1,
-    ACTIONS(48), 1,
+    ACTIONS(53), 1,
       anon_sym_LT_PERCENT_PERCENT,
-    ACTIONS(50), 1,
-      anon_sym_LT_PERCENT,
     STATE(5), 1,
       aux_sym_content_repeat1,
-    ACTIONS(44), 6,
+    ACTIONS(55), 4,
+      anon_sym_LT_PERCENT,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(49), 7,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [21] = 5,
-    ACTIONS(54), 1,
+  [25] = 5,
+    ACTIONS(59), 1,
       aux_sym_content_token1,
-    ACTIONS(57), 1,
+    ACTIONS(62), 1,
       anon_sym_LT_PERCENT_PERCENT,
-    ACTIONS(60), 1,
-      anon_sym_LT_PERCENT,
     STATE(5), 1,
       aux_sym_content_repeat1,
-    ACTIONS(52), 6,
+    ACTIONS(65), 4,
+      anon_sym_LT_PERCENT,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(57), 7,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [42] = 2,
-    ACTIONS(64), 2,
+  [50] = 2,
+    ACTIONS(69), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(62), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(67), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [56] = 2,
-    ACTIONS(68), 2,
+  [68] = 2,
+    ACTIONS(73), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(66), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(71), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [70] = 2,
-    ACTIONS(72), 2,
+  [86] = 2,
+    ACTIONS(77), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(70), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(75), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [84] = 2,
-    ACTIONS(76), 2,
+  [104] = 2,
+    ACTIONS(81), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(74), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(79), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [98] = 2,
-    ACTIONS(80), 2,
+  [122] = 2,
+    ACTIONS(85), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(78), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(83), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
-      anon_sym_LT_PERCENT_DASH,
-      anon_sym_LT_PERCENT_POUND,
-      anon_sym_LT_PERCENTgraphql,
-  [112] = 2,
-    ACTIONS(84), 2,
-      aux_sym_content_token1,
-      anon_sym_LT_PERCENT,
-    ACTIONS(82), 7,
-      ts_builtin_sym_end,
-      anon_sym_LT_PERCENT_PERCENT,
-      anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
-      anon_sym_LT_PERCENT_DASH,
-      anon_sym_LT_PERCENT_POUND,
-      anon_sym_LT_PERCENTgraphql,
-  [126] = 2,
-    ACTIONS(88), 2,
-      aux_sym_content_token1,
-      anon_sym_LT_PERCENT,
-    ACTIONS(86), 7,
-      ts_builtin_sym_end,
-      anon_sym_LT_PERCENT_PERCENT,
-      anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
   [140] = 2,
-    ACTIONS(92), 2,
+    ACTIONS(89), 5,
       aux_sym_content_token1,
       anon_sym_LT_PERCENT,
-    ACTIONS(90), 7,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(87), 8,
       ts_builtin_sym_end,
       anon_sym_LT_PERCENT_PERCENT,
       anon_sym_LT_PERCENT_,
-      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
       anon_sym_LT_PERCENT_DASH,
       anon_sym_LT_PERCENT_POUND,
       anon_sym_LT_PERCENTgraphql,
-  [154] = 5,
-    ACTIONS(94), 1,
+  [158] = 2,
+    ACTIONS(93), 5,
+      aux_sym_content_token1,
+      anon_sym_LT_PERCENT,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(91), 8,
+      ts_builtin_sym_end,
+      anon_sym_LT_PERCENT_PERCENT,
+      anon_sym_LT_PERCENT_,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
+      anon_sym_LT_PERCENT_DASH,
+      anon_sym_LT_PERCENT_POUND,
+      anon_sym_LT_PERCENTgraphql,
+  [176] = 2,
+    ACTIONS(97), 5,
+      aux_sym_content_token1,
+      anon_sym_LT_PERCENT,
+      anon_sym_LT_PERCENT_PIPE,
+      anon_sym_LT_PERCENT_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ,
+    ACTIONS(95), 8,
+      ts_builtin_sym_end,
+      anon_sym_LT_PERCENT_PERCENT,
+      anon_sym_LT_PERCENT_,
+      anon_sym_LT_PERCENT_EQ_EQ,
+      anon_sym_LT_PERCENT_PIPE_EQ_EQ,
+      anon_sym_LT_PERCENT_DASH,
+      anon_sym_LT_PERCENT_POUND,
+      anon_sym_LT_PERCENTgraphql,
+  [194] = 5,
+    ACTIONS(99), 1,
       aux_sym_code_token1,
-    ACTIONS(96), 1,
+    ACTIONS(101), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    STATE(16), 1,
+    STATE(19), 1,
       aux_sym_code_repeat1,
     STATE(25), 1,
       sym_code,
-    ACTIONS(98), 3,
+    ACTIONS(103), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
-      anon_sym__PERCENT_GT,
-  [172] = 5,
-    ACTIONS(100), 1,
+      anon_sym_EQ_PERCENT_GT,
+  [212] = 5,
+    ACTIONS(105), 1,
       aux_sym_code_token1,
-    ACTIONS(102), 1,
+    ACTIONS(107), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    STATE(18), 1,
+    STATE(16), 1,
       aux_sym_code_repeat1,
     STATE(24), 1,
       sym_code,
-    ACTIONS(104), 3,
-      anon_sym_PERCENT_GT,
-      anon_sym_DASH_PERCENT_GT,
-      anon_sym_EQ_PERCENT_GT,
-  [190] = 4,
-    ACTIONS(106), 1,
-      aux_sym_code_token1,
-    ACTIONS(108), 1,
-      anon_sym_PERCENT_PERCENT_GT,
-    STATE(17), 1,
-      aux_sym_code_repeat1,
-    ACTIONS(110), 3,
+    ACTIONS(109), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
       anon_sym__PERCENT_GT,
-  [205] = 4,
-    ACTIONS(112), 1,
+  [230] = 4,
+    ACTIONS(111), 1,
       aux_sym_code_token1,
-    ACTIONS(115), 1,
+    ACTIONS(113), 1,
       anon_sym_PERCENT_PERCENT_GT,
     STATE(17), 1,
       aux_sym_code_repeat1,
-    ACTIONS(118), 3,
+    ACTIONS(115), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
       anon_sym__PERCENT_GT,
-  [220] = 4,
+  [245] = 4,
+    ACTIONS(117), 1,
+      aux_sym_code_token1,
     ACTIONS(120), 1,
-      aux_sym_code_token1,
-    ACTIONS(122), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    STATE(19), 1,
+    STATE(17), 1,
       aux_sym_code_repeat1,
-    ACTIONS(110), 3,
+    ACTIONS(123), 3,
+      anon_sym_PERCENT_GT,
+      anon_sym_DASH_PERCENT_GT,
+      anon_sym__PERCENT_GT,
+  [260] = 4,
+    ACTIONS(125), 1,
+      aux_sym_code_token1,
+    ACTIONS(128), 1,
+      anon_sym_PERCENT_PERCENT_GT,
+    STATE(18), 1,
+      aux_sym_code_repeat1,
+    ACTIONS(123), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
       anon_sym_EQ_PERCENT_GT,
-  [235] = 4,
-    ACTIONS(124), 1,
+  [275] = 4,
+    ACTIONS(131), 1,
       aux_sym_code_token1,
-    ACTIONS(127), 1,
+    ACTIONS(133), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    STATE(19), 1,
+    STATE(18), 1,
       aux_sym_code_repeat1,
-    ACTIONS(118), 3,
+    ACTIONS(115), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
       anon_sym_EQ_PERCENT_GT,
-  [250] = 5,
-    ACTIONS(130), 1,
+  [290] = 5,
+    ACTIONS(135), 1,
       aux_sym_code_token1,
-    ACTIONS(132), 1,
+    ACTIONS(137), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    ACTIONS(134), 1,
+    ACTIONS(139), 1,
       anon_sym_PERCENT_GT,
     STATE(22), 1,
       aux_sym_code_repeat1,
-    STATE(26), 1,
+    STATE(28), 1,
       sym_code,
-  [266] = 5,
-    ACTIONS(130), 1,
+  [306] = 5,
+    ACTIONS(135), 1,
       aux_sym_code_token1,
-    ACTIONS(132), 1,
+    ACTIONS(137), 1,
       anon_sym_PERCENT_PERCENT_GT,
-    ACTIONS(136), 1,
+    ACTIONS(141), 1,
       anon_sym_PERCENT_GT,
     STATE(22), 1,
       aux_sym_code_repeat1,
     STATE(27), 1,
       sym_code,
-  [282] = 4,
-    ACTIONS(110), 1,
+  [322] = 4,
+    ACTIONS(115), 1,
       anon_sym_PERCENT_GT,
-    ACTIONS(138), 1,
-      aux_sym_code_token1,
-    ACTIONS(140), 1,
-      anon_sym_PERCENT_PERCENT_GT,
-    STATE(23), 1,
-      aux_sym_code_repeat1,
-  [295] = 4,
-    ACTIONS(118), 1,
-      anon_sym_PERCENT_GT,
-    ACTIONS(142), 1,
+    ACTIONS(143), 1,
       aux_sym_code_token1,
     ACTIONS(145), 1,
       anon_sym_PERCENT_PERCENT_GT,
     STATE(23), 1,
       aux_sym_code_repeat1,
-  [308] = 1,
-    ACTIONS(148), 3,
+  [335] = 4,
+    ACTIONS(123), 1,
       anon_sym_PERCENT_GT,
-      anon_sym_DASH_PERCENT_GT,
-      anon_sym_EQ_PERCENT_GT,
-  [314] = 1,
-    ACTIONS(150), 3,
+    ACTIONS(147), 1,
+      aux_sym_code_token1,
+    ACTIONS(150), 1,
+      anon_sym_PERCENT_PERCENT_GT,
+    STATE(23), 1,
+      aux_sym_code_repeat1,
+  [348] = 1,
+    ACTIONS(153), 3,
       anon_sym_PERCENT_GT,
       anon_sym_DASH_PERCENT_GT,
       anon_sym__PERCENT_GT,
-  [320] = 1,
-    ACTIONS(152), 1,
+  [354] = 1,
+    ACTIONS(155), 3,
       anon_sym_PERCENT_GT,
-  [324] = 1,
-    ACTIONS(154), 1,
-      anon_sym_PERCENT_GT,
-  [328] = 1,
-    ACTIONS(156), 1,
+      anon_sym_DASH_PERCENT_GT,
+      anon_sym_EQ_PERCENT_GT,
+  [360] = 1,
+    ACTIONS(157), 1,
       ts_builtin_sym_end,
+  [364] = 1,
+    ACTIONS(159), 1,
+      anon_sym_PERCENT_GT,
+  [368] = 1,
+    ACTIONS(161), 1,
+      anon_sym_PERCENT_GT,
 };
 
 static const uint32_t ts_small_parse_table_map[] = {
   [SMALL_STATE(4)] = 0,
-  [SMALL_STATE(5)] = 21,
-  [SMALL_STATE(6)] = 42,
-  [SMALL_STATE(7)] = 56,
-  [SMALL_STATE(8)] = 70,
-  [SMALL_STATE(9)] = 84,
-  [SMALL_STATE(10)] = 98,
-  [SMALL_STATE(11)] = 112,
-  [SMALL_STATE(12)] = 126,
-  [SMALL_STATE(13)] = 140,
-  [SMALL_STATE(14)] = 154,
-  [SMALL_STATE(15)] = 172,
-  [SMALL_STATE(16)] = 190,
-  [SMALL_STATE(17)] = 205,
-  [SMALL_STATE(18)] = 220,
-  [SMALL_STATE(19)] = 235,
-  [SMALL_STATE(20)] = 250,
-  [SMALL_STATE(21)] = 266,
-  [SMALL_STATE(22)] = 282,
-  [SMALL_STATE(23)] = 295,
-  [SMALL_STATE(24)] = 308,
-  [SMALL_STATE(25)] = 314,
-  [SMALL_STATE(26)] = 320,
-  [SMALL_STATE(27)] = 324,
-  [SMALL_STATE(28)] = 328,
+  [SMALL_STATE(5)] = 25,
+  [SMALL_STATE(6)] = 50,
+  [SMALL_STATE(7)] = 68,
+  [SMALL_STATE(8)] = 86,
+  [SMALL_STATE(9)] = 104,
+  [SMALL_STATE(10)] = 122,
+  [SMALL_STATE(11)] = 140,
+  [SMALL_STATE(12)] = 158,
+  [SMALL_STATE(13)] = 176,
+  [SMALL_STATE(14)] = 194,
+  [SMALL_STATE(15)] = 212,
+  [SMALL_STATE(16)] = 230,
+  [SMALL_STATE(17)] = 245,
+  [SMALL_STATE(18)] = 260,
+  [SMALL_STATE(19)] = 275,
+  [SMALL_STATE(20)] = 290,
+  [SMALL_STATE(21)] = 306,
+  [SMALL_STATE(22)] = 322,
+  [SMALL_STATE(23)] = 335,
+  [SMALL_STATE(24)] = 348,
+  [SMALL_STATE(25)] = 354,
+  [SMALL_STATE(26)] = 360,
+  [SMALL_STATE(27)] = 364,
+  [SMALL_STATE(28)] = 368,
 };
 
 static const TSParseActionEntry ts_parse_actions[] = {
   [0] = {.entry = {.count = 0, .reusable = false}},
   [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
-  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template, 0),
+  [3] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template, 0, 0, 0),
   [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
   [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
-  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
-  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
-  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
-  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
-  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
-  [19] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2),
-  [21] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(4),
-  [24] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(4),
-  [27] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(14),
-  [30] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(14),
-  [33] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(15),
-  [36] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(20),
-  [39] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2), SHIFT_REPEAT(21),
-  [42] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template, 1),
-  [44] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_content, 1),
-  [46] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
-  [48] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
-  [50] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_content, 1),
-  [52] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_content_repeat1, 2),
-  [54] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_content_repeat1, 2), SHIFT_REPEAT(5),
-  [57] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_content_repeat1, 2), SHIFT_REPEAT(5),
-  [60] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_content_repeat1, 2),
-  [62] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_directive, 2),
-  [64] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comment_directive, 2),
-  [66] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_directive, 3),
-  [68] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_directive, 3),
-  [70] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graphql_directive, 3),
-  [72] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graphql_directive, 3),
-  [74] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2),
-  [76] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2),
-  [78] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_directive, 3, .production_id = 1),
-  [80] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comment_directive, 3, .production_id = 1),
-  [82] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 3),
-  [84] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 3),
-  [86] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_directive, 2),
-  [88] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_directive, 2),
-  [90] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graphql_directive, 2),
-  [92] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graphql_directive, 2),
-  [94] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
-  [96] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
-  [98] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
-  [100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
-  [102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
-  [104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
-  [106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
-  [108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
-  [110] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code, 1),
-  [112] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(17),
-  [115] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(17),
-  [118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2),
-  [120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
-  [122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
-  [124] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(19),
-  [127] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(19),
-  [130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
-  [132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
-  [134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
-  [136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
-  [138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
-  [140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
-  [142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(23),
-  [145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2), SHIFT_REPEAT(23),
-  [148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
-  [150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
-  [152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
-  [154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
-  [156] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
+  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
+  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
+  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
+  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
+  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
+  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
+  [21] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template, 1, 0, 0),
+  [23] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0),
+  [25] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
+  [28] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
+  [31] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(15),
+  [34] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(15),
+  [37] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(14),
+  [40] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(14),
+  [43] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(20),
+  [46] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_repeat1, 2, 0, 0), SHIFT_REPEAT(21),
+  [49] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_content, 1, 0, 0),
+  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
+  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
+  [55] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_content, 1, 0, 0),
+  [57] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_content_repeat1, 2, 0, 0),
+  [59] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_content_repeat1, 2, 0, 0), SHIFT_REPEAT(5),
+  [62] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_content_repeat1, 2, 0, 0), SHIFT_REPEAT(5),
+  [65] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_content_repeat1, 2, 0, 0),
+  [67] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 2, 0, 0),
+  [69] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 2, 0, 0),
+  [71] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_directive, 2, 0, 0),
+  [73] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_directive, 2, 0, 0),
+  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graphql_directive, 3, 0, 0),
+  [77] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graphql_directive, 3, 0, 0),
+  [79] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_directive, 3, 0, 0),
+  [81] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_directive, 3, 0, 0),
+  [83] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_directive, 2, 0, 0),
+  [85] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comment_directive, 2, 0, 0),
+  [87] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graphql_directive, 2, 0, 0),
+  [89] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graphql_directive, 2, 0, 0),
+  [91] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_directive, 3, 0, 0),
+  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_directive, 3, 0, 0),
+  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_directive, 3, 0, 1),
+  [97] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comment_directive, 3, 0, 1),
+  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(19),
+  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
+  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
+  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
+  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
+  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
+  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
+  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
+  [115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_code, 1, 0, 0),
+  [117] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(17),
+  [120] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(17),
+  [123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0),
+  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(18),
+  [128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(18),
+  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
+  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
+  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
+  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
+  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
+  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
+  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
+  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
+  [147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(23),
+  [150] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_code_repeat1, 2, 0, 0), SHIFT_REPEAT(23),
+  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
+  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
+  [157] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
+  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
+  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
 };
 
 #ifdef __cplusplus
 extern "C" {
 #endif
-#ifdef _WIN32
-#define extern __declspec(dllexport)
+#ifdef TREE_SITTER_HIDE_SYMBOLS
+#define TS_PUBLIC
+#elif defined(_WIN32)
+#define TS_PUBLIC __declspec(dllexport)
+#else
+#define TS_PUBLIC __attribute__((visibility("default")))
 #endif
 
-extern const TSLanguage *tree_sitter_embedded_template(void) {
+TS_PUBLIC const TSLanguage *tree_sitter_embedded_template(void) {
   static const TSLanguage language = {
     .version = LANGUAGE_VERSION,
     .symbol_count = SYMBOL_COUNT,
